OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакти",
    "All contacts" : "Сите контакти",
    "Groups" : "Групи",
    "New contact" : "Нов контакт",
    "First name" : "Име",
    "Last name" : "Презиме",
    "Nickname" : "Прекар",
    "Additional names" : "Дополнителни имиња",
    "Notes" : "Белешки",
    "Website" : "Веб сајт",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Дома",
    "Work" : "Работа",
    "Other" : "Останато",
    "Address" : "Адреса",
    "City" : "Град",
    "State or province" : "Град или провинција",
    "Postal code" : "Поштенски број",
    "Country" : "Држава",
    "Birthday" : "Роденден",
    "Email" : "Е-пошта",
    "Instant messaging" : "Инстантни пораки",
    "Phone" : "Телефон",
    "Mobile" : "Мобилен",
    "Fax" : "Факс",
    "Fax home" : "Fax дома",
    "Fax work" : "Fax на работа",
    "Pager" : "Пејџер",
    "Voice" : "Глас"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
